Chapter 1: Strong Lensing
=========================

In chapter 1, we introduce you to strong gravitational lensing and the core **PyAutoLens** API.

You can start the tutorials right now by going to `our binder <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/HEAD>`_
and navigating to the folder ``notebooks/howtolens/chapter_1_introduction``. They are also on the `autolens_workspace <https://github.com/Jammy2211/autolens_workspace>`_.

The chapter contains the following tutorials:

`Tutorial 0: Visualization <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_1_introduction/tutorial_0_visualization.ipynb>`_
- Setting up visualization.

`Tutorial 1: Grids <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_1_introduction/tutorial_1_grids.ipynb>`_
- Uniform grids of (y,x) coordinates used for ray-traicng.

`Tutorial 2: Profiles <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_1_introduction/tutorial_2_profiles.ipynb>`_
- Analytic profiles representing light and mass distributions.

`Tutorial 3: Galaxies <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_1_introduction/tutorial_3_galaxies.ipynb>`_
- The objects that make up a strong lens.

`Tutorial 4: Planes <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_1_introduction/tutorial_4 planes.ipynb>`_
- Groups of galaxies at a common redshift.

`Tutorial 5: Ray Tracing <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_1_introduction/tutorial_5_ray_tracing.ipynb>`_
- Using Grids and Galaxies to perform strong lens ray-tracing!

`Tutorial 6: More Ray Tracing <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_1_introduction/tutorial_6_more_ray_tracing.ipynb>`_
- Advanced strong lens ray-tracing.

`Tutorial 7: Data <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_1_introduction/tutorial_7_data.ipynb>`_
- Loading and inspecting telescope imaging ``data`` of a strong lens.

`Tutorial 8: Fitting <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_1_introduction/tutorial_8_fittingn.ipynb>`_
- Fitting ``data`` with a strong lens model.

`Tutorial 9: Summary <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_1_introduction/tutorial_9_summary.ipynb>`_
- A summary of the chapter.